const assert = require('assert')
const Magento2Api = require('../src/index')

describe('Magento2Api Instance', function () {
  it("won't instantiate work with empty api object", async function () {
    assert.throws(
      () => new Magento2Api()
    )

    assert.throws(
      () => new Magento2Api({})
    )
  })

  it("instantiate with just url", async function () {
    var api = new Magento2Api({ api: { url: 'https://localhost' }})
    assert.ok(api)
  })

  it('gets axios', function () {
    var api = new Magento2Api({ api: { url: 'https://localhost' }})
    assert.ok(api.axios)
  })

  it('instantiates with all details', function () {
    var api = new Magento2Api({ api: {
      url: 'https://localhost',
      consumerKey: 'probably',
      consumerSecret: 'this',
      accessToken: 'wont',
      tokenSecret: 'work',
    }})
    assert.ok(api)
  })

  it('correctly encodes parameter values', async function () {
    var api = new Magento2Api({ api: { url: 'https://localhost' }})

    var uri = api.axios.getUri({
      method: "GET",
      url: "non-existent-path",
      params: {
        test: '/',
        other: [ 'brackets', '[]' ],
      }
    })

    assert.strictEqual(
      uri,
      'non-existent-path?test=%2F&other[0]=brackets&other[1]=%5B%5D'
    )
  })
})
